import 'dart:io';

import 'package:flutter_l10n/log.dart';
import 'package:flutter_l10n/reader.dart';
import 'package:flutter_l10n/writer.dart';

main(List<String> args) {
  initLogging();
  String inputPath = 'lib/';
  String outputPath = 'lib/l10n/';
  Directory inputDir = Directory(inputPath);
  if (!inputDir.existsSync()) {
    throw FileSystemException('Directory not exists', inputDir.path);
  }
  List<FileSystemEntity> arbFiles =
      inputDir.listSync(recursive: true).where((f) {
    return FileSystemEntity.isFileSync(f.path) && f.path.endsWith('.arb');
  }).toList();
  if (arbFiles.isEmpty) {
    log.info('No arb files found in ${inputDir.path}.');
    exit(0);
  }

  Map<File, Map<String, dynamic>> all = {};
  arbFiles.forEach((arb) {
    if (arb is File) {
      Map<String, dynamic> arbMap = parseArb(arb);
      if (arbMap != null) {
        all[arb] = arbMap;
      }
    }
  });

  if (all.isEmpty) {
    exit(0);
  }

  Directory outputDir = Directory(outputPath);
  if (!outputDir.existsSync()) {
    outputDir.createSync(recursive: true);
  }

  writeClasses(outputDir, all);
}
